ProgressBar class

Inheritance

Constructors

ProgressBar({Key? key, Color backgroundColor = const Color(0xeecccccc), Color progressColor = const Color(0xffADDE98), bool showProgressText = false, Color progressTextColor = const Color(0xff333333), double progressTextSize = 11, double maxValue = 100, double progress = 0, double width = 100, double height = 16, double radius = 20, OnBuildProgressBarCall? buildCall})
const

Properties

backgroundColor → Color
进度背景颜色
final
buildCall → OnBuildProgressBarCall?
组件构建完成后回调
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
组件宽度、高度
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue → double
进度最大值
final
progress → double
当前进度值
final
progressColor → Color
进度颜色
final
progressTextColor → Color
文本字体颜色
final
progressTextSize → double
文本字体大小
final
radius → double
组件圆角大小
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showProgressText → bool
显示进度文本
final
width → double
组件宽度、高度
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ProgressBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited