ButtonArgs class

Constructors

ButtonArgs({double? width, double height = 40, String text = '', Color color = const Color(0xFF999999), FontWeight fontWeight = FontWeight.normal, String action = '', double fontSize = 16, Color backgroundColor = Colors.transparent, EdgeInsetsGeometry margin = EdgeInsets.zero, BorderRadius borderRadius = BorderRadius.zero})

Properties

action → String
唯一标识符
final
backgroundColor → Color
按钮背景
final
borderRadius → BorderRadius
按钮边框圆角
final
color → Color
按钮文本颜色
final
fontSize → double
字体大小
final
fontWeight → FontWeight
字体权重
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
按钮高度
final
margin → EdgeInsetsGeometry
按钮外边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
按钮文本
final
width → double?
按钮宽度
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited