RefreshHeaderHandler mixin

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeText() → String
刷新完成提示文本
headerTextColor() → int
头部文本颜色
idleText() → String
未达到刷新条件时提示文本
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshFailedText() → String
刷新失败
refreshHeight() → double
刷新视图高度
refreshingText() → String
数据刷新中
releaseText() → String
松开刷新数据
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited