RefreshInitManager class

Constructors

RefreshInitManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

headerHandler() → RefreshHeaderHandler?
loadHandler() → RefreshLoadHandler?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetConfig(dynamic headerInitHandler) → void
重置配置 headerInitHandler 刷新组件初始化对象
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → RefreshInitManager
no setter