RefreshWidget class

Inheritance

Constructors

RefreshWidget({Key? key, RefreshListStyle listStyle = RefreshListStyle.list, Widget child = const SizedBox(), List<Widget>? slivers, OnRefreshCall? onRefresh, OnLoadCall? onLoad, bool enableRefresh = true, bool enableLoad = true, Widget? emptyWidget, bool isVisibilityFirstLoadWidget = true, bool enableControlFinishRefresh = true, Footer? footer, RefreshInitCall? initCall, double scrollMaxRatioLoad = 0.7, Widget? loadIndicatorWidget, ScrollController? scrollController})
const

Properties

child → Widget
刷新对象视图
final
emptyWidget → Widget?
空视图
final
enableControlFinishRefresh → bool
true-需要主动调用结束刷新状态,false-自动处理;
final
enableLoad → bool
启用加载功能
final
enableRefresh → bool
启用刷新功能
final
底部组件
final
hashCode → int
The hash code for this object.
no setterinherited
initCall → RefreshInitCall?
final
isVisibilityFirstLoadWidget → bool
是否显示首次加载效果(默认显示)
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listStyle → RefreshListStyle
列表样式
final
loadIndicatorWidget → Widget?
加载指示器组件
final
onLoad → RefreshInitCall?
加载回调
final
onRefresh → RefreshInitCall?
刷新回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
滚动控制器
final
scrollMaxRatioLoad → double
滚动超过最大比例加载下一页数据(范围:0~1)
final
slivers → List<Widget>?
slivers为空时加载child
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _RefreshWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited