ElementListBuilder<M extends ElementListModel, D> class abstract

Inheritance

Constructors

ElementListBuilder()

Properties

backgroundAlignment → AlignmentGeometry
背景对齐方式
no setter
backgroundColor → Color
背景
no setter
backgroundImage → String
背景图片
no setter
borderRadius → BorderRadiusGeometry
容器边框圆角
no setter
enableLoad → bool
启用加载
no setter
enableRefresh → bool
启用刷新
no setter
hashCode → int
The hash code for this object.
no setterinherited
model → M
no setterinherited
padding → EdgeInsetsGeometry
内边距
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → D?
no setterinherited

Methods

builder(BuildContext context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBuildBottomView(BuildContext context) → Widget
渲染视图bottom对象
onBuildComplete() → void
inherited
onBuildHeadView() → Widget
构建页面顶部视图
onBuildInit() → void
构建初始化
inherited
onEmptyRenderObject() → Widget
空视图对象
onRenderObject(List<Widget> list) → void
构建渲染对象
onRenderTopObject(List<Widget> list) → void
渲染视图top对象
setModel(M model) → void
inherited
setSource(D? data) → void
inherited
subscribeNotifierWidget(M model, ConsumerElementBuilder<M> builder) → Widget
订阅消费组件 model 订阅模型 builder 组件构建器
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited