TextFieldItem class

Constructors

TextFieldItem({String? hintText, TextStyle hintStyle = const TextStyle(color: Color(0xff999999), fontSize: 12), String? labelText, TextStyle labelStyle = const TextStyle(color: Color(0xff333333), fontSize: 13), String? prefix, TextStyle? prefixStyle, TextStyle tipTextStyle = const TextStyle(color: Color(0x99ff2e18), fontSize: 12), String? counterText, TextStyle? counterStyle, Widget? prefixWidget, Widget? suffixWidget, double underlineWidth = 1, Color underlineColor = const Color(0xffEFEFEF), Color errorUnderlineColor = const Color(0xffEFEFEF), String? tag, FormFieldValidator<String>? validator, double? maxWidth, double? maxHeight, double? height, bool enablePass = false, List<TextInputFormatter>? inputFormatters, TextInputType? keyboardType, List<ItemOption> menuItems = const [], String? defaultText, Offset? menuOffset, int minLines = 1, int maxLines = 1, AlignmentGeometry alignment = Alignment.centerLeft, TextAlign textAlign = TextAlign.left, bool visible = true, BoxBorder? border, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? contentPadding, BoxConstraints? prefixIconConstraints, dynamic onSubmitted(String text)?, bool defaultShowFocus = false})

Properties

alignment ↔ AlignmentGeometry
内容对齐
getter/setter pair
border → BoxBorder?
边框装饰
final
borderRadius → BorderRadiusGeometry?
边框圆角
final
contentPadding → EdgeInsetsGeometry?
内边距
final
counterStyle → TextStyle?
右下角文本样式
final
counterText → String?
右下角显示文本
final
defaultShowFocus → bool
默认是否显示光标
final
defaultText ↔ String?
默认文本
getter/setter pair
enablePass ↔ bool
启用密码
getter/setter pair
errorUnderlineColor → Color
错误下划线颜色
final
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
组件高度
getter/setter pair
hintStyle → TextStyle
提示文本
final
hintText → String?
提示文本
final
inputFormatters ↔ List<TextInputFormatter>?
输入限制
getter/setter pair
keyboardType ↔ TextInputType?
键盘输入类型
getter/setter pair
labelStyle → TextStyle
输入文本样式
final
labelText → String?
输入文本后左上角提示文本
final
maxHeight ↔ double?
最大高度
getter/setter pair
maxLines ↔ int
最大行号
getter/setter pair
maxWidth ↔ double?
最大宽度
getter/setter pair
菜单选项
getter/setter pair
菜单偏移量
getter/setter pair
minLines ↔ int
最小行号
getter/setter pair
onSubmitted → dynamic Function(String text)?
input enter event
final
prefix → String?
前缀文本
final
prefixIconConstraints → BoxConstraints?
前缀图标约束
final
prefixStyle → TextStyle?
前缀文本样式
final
prefixWidget → Widget?
输入文本前组件
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixWidget ↔ Widget?
输入文本后组件
getter/setter pair
tag → String?
选项标识
final
textAlign ↔ TextAlign
内容对象
getter/setter pair
tipTextStyle → TextStyle
输入框下面的提示信息样式
final
underlineColor → Color
下划线颜色
final
underlineWidth → double
下划线宽度
final
validator → FormFieldValidator<String>?
字段验证对象,回调参数为当前输入值,验证不通过时返回具体错误信息,通过时返回null;
final
visible ↔ bool
是否隐藏组件
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited