TextFieldWidget class

Inheritance

Constructors

TextFieldWidget({Key? key, TextFieldItem? fieldItem, OnTextFieldListener? fieldListener, OnFieldCall? fieldCall, EdgeInsetsGeometry? margin, String? defaultText, double? textMenuItemWidth, double? textMenuItemHeight, OnTextMenuItemClick? menuItemClick, Color? menuIconColor})
const

Properties

defaultText → String?
默认文本
final
fieldCall → OnFieldCall?
final
fieldItem → TextFieldItem?
final
fieldListener → OnTextFieldListener?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
输入框外边距
final
菜单图标颜色
final
文本菜单选项单击事件
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textMenuItemHeight → double?
文本菜单选项高度
final
textMenuItemWidth → double?
文本菜单选项宽度
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextFieldWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited