TextFields class

Inheritance

Constructors

TextFields({Key? key, List<TextFieldItem>? items, OnTextFieldListener? fieldListener, double? maxWidth, double? maxHeight, OnFieldsControllerCall? controllerCall, EdgeInsetsGeometry? itemMargin, double textMenuItemHeight = 36, OnTextMenuItemClick? menuItemClick, Color menuIconColor = const Color(0xff262626), Color? backgroundColor, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin})
const

Properties

backgroundColor → Color?
背景颜色
final
borderRadius → BorderRadiusGeometry?
边框圆角
final
controllerCall → OnFieldsControllerCall?
final
fieldListener → OnTextFieldListener?
final
hashCode → int
The hash code for this object.
no setterinherited
itemMargin → EdgeInsetsGeometry?
输入框外边距
final
items → List<TextFieldItem>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
组件外边距
final
maxHeight → double?
最大高度
final
maxWidth → double?
最大宽度
final
菜单图标颜色
final
文本菜单选项单击事件
final
padding → EdgeInsetsGeometry?
组件内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textMenuItemHeight → double
文本菜单选项高度
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextFieldsState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited